/* aa.h 
Contains the classes for handling a data point - particle, the coordinate system CoordSys and the 
Stackel fitting class StackFit. Also contains prototypes for printing functions.
*/

#ifndef aa_H
#define aa_H
extern int FLAG;
extern double ACCURACY;
#include <fstream>
//=================================================================================================

class particle{
  // Structure for representing each data point read in from file
  public:
  	double x[3];
  	double v[3];
  	double Rz[2];
  	double vRvz[2];
  	double phi;
  	double tau[6];
  	double J[3];
  	double Int[3];
  	double limits[4];
	double lz;
  	double Angs[3];
  	double freq[3];
  	double hess[3][3];
  	int FLAG;
  	// Three points on orbit to define limits of integrals
	double R1[4]; double R2[4]; double z1[4];
  	
  	particle(double x1, double x2, double x3, double v1, double v2, double v3);
  	particle(double R1, double R2, double vR1, double vphi1, double vz1);
  	particle(double xx[],int type);
  	virtual ~particle(){}
};

//=================================================================================================

class CoordSys{
// Handles coordinate system transformations and definition of Stackel potential
	public:
		double Alpha;
		double Gamma;
  		
		CoordSys(double A, double G);
		virtual ~CoordSys() {}
		void xyz2tau(double [],double []);
		void Rz2tau(double [],double []);
		void xv2taudot(double [3],double [3],double [3]);
		void tau2xyz(double [3],double [3],double [3],double [3]);
		void tau2Rz(double tau[2], double x[2]);
		void RzvRvz2tautaudot(double x[4], double tau[4]);
		double I3(double tau[4], double E, double I2);
		void RzvRvz2tautaudot(particle &star);
		void calcIntegrals(particle &star);
		};

//=================================================================================================
// Action, Angle and isolating integral calculations //
void stackfitActionsAngles(double x[6], double aa[6]);
void stackfitActionsAnglesPolar(double x[5], double aa[6]);

class StackFit{
	public:
		StackFit(double,double,double);
		void ActionsAngles(double x[6], double aa[6]);
		void ActionsAnglesPolar(double x[5], double aa[6]);
		virtual ~StackFit() {}
		void Actions(CoordSys &,particle &);
  		void Angles(CoordSys &,particle &);
};

//=================================================================================================
// Printing Functions //
void FilePrint(std::ofstream &, particle &);
void nicePrint(float j[2], double I2, double ang[3], double freq[3]);
void printHess(double hess[3][3]);

#endif
//=================================================================================================