/*

GFn.cpp

Jason Sanders, jason.sanders@physics.ox.ac.uk

functions to calculate G(tau) using the best fit potential found in fitpot.cpp

*/
//=================================================================================================

#include <iostream>
#include "GFn.h"
#include "fitpot.h"
#include "PotMN.h"
#include "utils.h"

#define TINY 1e-10

//=================================================================================================
// Interpolation Routines

// Grids for splinterpolation 
double *lambdagrid;
double *flamgrid;
double *fnugrid;
double *nugrid;
double *y2Lamgrid;
double *y2Nugrid;

double flamINT(double lam){
	// Splinterpolates flam table if lam lies inside range, else integrates to find flam
	if(lam<lambdagrid[0] || lam>lambdagrid[DATAPOINTS-1]){
		lamIntTmp=lam;
		return ((GaussLegendreQuad(&chiNu,numinus,nuplus)/N)-0.5*chibar);
		}
	else{
	double flamInter = interp_splint(lambdagrid,flamgrid,y2Lamgrid,DATAPOINTS,lam);//
	return flamInter;
	}
	}

double fnuINT(double nu){
	// Splinterpolates fnu table if nu lies inside range, else integrates to find fnu
	if(nu<nugrid[0] || nu>nugrid[DATAPOINTS-1]){
		nuIntTmp=nu;
		return (-(GaussLegendreQuad(&chiLam,lambdaminus,lambdaplus)/L)+0.5*chibar);
		}
	else{
	double fnuInter = interp_splint(nugrid,fnugrid,y2Nugrid,DATAPOINTS,nu);//
	return fnuInter;
	}
	}

//=================================================================================================
// Potential Functions

  double G(double tau){
  // de Zeeuw G(tau)
		if(tau==-Gamma){tau=tau+TINY;}
 		if(tau>-Alpha){	return flamINT(tau)/(tau+Gamma);}
		else{return fnuINT(tau)/(tau+Gamma);}
  	}
  
  double GPrime(double tau){
    //    computes G'(tau) - necessary for forces
    return (G(tau+0.0005)-G(tau-0.0005))/0.001;
  }
  
  double BigF(double tau){
  // de Zeeuw F(tau)
  		if(tau==-Gamma){tau=tau+TINY;}
 		if(tau>-Alpha){	return flamINT(tau)*(tau+Alpha);}
		else{return fnuINT(tau)*(tau+Alpha);}
  	}

//=================================================================================================