/*

PotMN.cpp

Jason Sanders, jason.sanders@physics.ox.ac.uk, adapted from code by Paul McMillan 

contains definition of potential to fit - here we use Miyamoto-Nagai as an example

Phi(R,z) = -GM/(R*R+(a+sqrt(z^2+b^2))^2)

*/

//=================================================================================================

#include <fstream>
#include <iostream>
#include <cmath>
#include <stdio.h>
#include "utils.h"

//=================================================================================================
// Potential parameters
double A, GM, Bq;

//=================================================================================================
// Potential functions

void initPhi(double Mass, double a, double b){
	A=a;GM=Mass;Bq=b*b;
	return;
	}

double Phi(double R, double z)
{
  double AZB=A+sqrt(z*z+Bq);
  return -GM/sqrt(R*R+AZB*AZB);
}

void dPhi (double R, double z, double& dPdR,double& dPdz)
{
  double  ZB=sqrt(z*z+Bq), AZB = A + ZB,
    F = 1./(R*R+AZB*AZB),rtF=sqrt(F);
  dPdR = GM*R*F*rtF;
  dPdz = ZB? GM*z*F*rtF*AZB/ZB : 0.;
  return;
}

//=================================================================================================